Coverage report

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
onionizer/onionizer/__about__.py | 1 | 1 | 0 | 0 | 0 | 0%
onionizer/onionizer/__init__.py | 1 | 0 | 0 | 0 | 0 | 100%
onionizer/onionizer/onionizer.py | 108 | 1 | 0 | 29 | 0 | 99%
onionizer/tests/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
onionizer/tests/conftest.py | 0 | 0 | 0 | 0 | 0 | 100%
onionizer/tests/test_onionizer.py | 188 | 9 | 0 | 0 | 0 | 95%
Total | 298 | 11 | 0 | 29 | 0 | 97%

No items found using the specified filter.